﻿using IRaCIS.Core.Domain.Share;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IRaCIS.Core.Application.Service.Reading.Dto
{
    /// <summary>
    /// 临床问题基本信息
    /// </summary>
    public class ClinicalQuestionBase
    {

        public Guid? Id { get; set; }

        /// <summary>
        /// 问题名称
        /// </summary>
        public string QuestionName { get; set; } = string.Empty;

        /// <summary>
        /// 问题英文名称
        /// </summary>
        public string QuestionEnName { get; set; } = string.Empty;

        /// <summary>
        /// 临床问题类型(分组，单选。)
        /// </summary>
        public ClinicalQuestionType ClinicalQuestionTypeEnum { get; set; }

        /// <summary>
        /// 问题标识
        /// </summary>
        public ClinicalQuestionMark? ClinicalQuestionMarkEnum { get; set; }

        /// <summary>
        /// 最大长度
        /// </summary>
        public int? MaxAnswerLength { get; set; }

        /// <summary>
        /// 临床数据选项类型(无，自定义)
        /// </summary>
        public ClinicalOptionType ClinicalOptionTypeEnum { get; set; }

        /// <summary>
        /// 分组Id
        /// </summary>
        public Guid? GroupId { get; set; }

        /// <summary>
        /// 自定义选项
        /// </summary>
        public string TypeValue { get; set; } = string.Empty;

        /// <summary>
        /// 字典Code
        /// </summary>
        public string DictionaryCode { get; set; } = string.Empty;

        /// <summary>
        /// 排序
        /// </summary>
        public int ShowOrder { get; set; } = 0;

        /// <summary>
        /// 是否必填
        /// </summary>
        public bool IsRequired { get; set; } = false;
    }

    /// <summary>
    /// 查询临床数据基类
    /// </summary>
    public class ClinicalQuestionQueryBase : PageInput
    {
        /// <summary>
        /// 问题名称
        /// </summary>
        public string QuestionName { get; set; } = string.Empty;
    }

    /// <summary>
    /// 获取项目临床数据
    /// </summary>
    public class TrialClinicalQuestionQuery : ClinicalQuestionQueryBase
    {
        public Guid TrialClinicalId { get; set; }
    }

    /// <summary>
    /// 获取项目分组
    /// </summary>
    public class GetTrialGroupDto
    {
        public Guid TrialClinicalId { get; set; }
    }



    /// <summary>
    /// 项目临床数据问题
    /// </summary>
    public class TrialClinicalQuestionDto: ClinicalQuestionBase
    {
        /// <summary>
        /// 项目临床数据Id
        /// </summary>
        public Guid TrialClinicalId { get; set; }
    }


    /// <summary>
    /// 获取系统临床数据
    /// </summary>
    public class SystemClinicalQuestionQuery : ClinicalQuestionQueryBase
    {
        public Guid SystemClinicalId { get; set; }
    }



    /// <summary>
    /// 系统临床数据问题
    /// </summary>
    public class SystemClinicalQuestionDto : ClinicalQuestionBase
    {
        /// <summary>
        /// 系统临床数据Id
        /// </summary>
        public Guid SystemClinicalId { get; set; }
    }

    /// <summary>
    /// 获取系统分组
    /// </summary>
    public class GetSystemGroupDto
    {
        public Guid SystemClinicalId { get; set; }
    }
}
